==> ejc-front-impl-3.0.1-20230116.032346-113-sources.jar: com/ejianc/foundation/front/business/ide/cache/IdeModulePageCache.java <==
package com.ejianc.foundation.front.business.ide.cache;

import java.util.Set;

import com.ejianc.foundation.front.business.ide.entity.IdeModule;
import com.ejianc.foundation.front.business.ide.entity.IdeModulePrivate;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.front.business.ide.entity.IdeModulePro;

@Component
public class IdeModulePageCache {

	public static final String DEFAULT_CHARSET = "UTF-8";

	// 当前appCode和pageCode的所有cacheKey
	private final static String MODULEPAGE_CACHE_KEYS = "modulepage_cache_keys:";
	// 当前模块的缓存Key
	private final static String CURRENT_MODULEPAGE_KEY = "current_modulepage_key:";

	@Autowired
	private RedisTemplate<String, Object> redisTemplate;

	/**
	 * 前端页面放入缓存
	 * 
	 * @param appCode
	 * @param pageCode
	 * @param orgId
	 */
	public void putModulePageCache(String appCode, String pageCode, String orgId, Object modulePro) {
		String modulePageCacheKey = MODULEPAGE_CACHE_KEYS + appCode + "-" + pageCode;
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		if (StringUtils.isNotBlank(orgId)) {
			currentModulePageKey = currentModulePageKey + "-" + orgId;
		}
		String jsonStr = JSONObject.toJSONString(modulePro);

		redisTemplate.opsForValue().set(currentModulePageKey, jsonStr);
		redisTemplate.opsForHash().put(modulePageCacheKey, currentModulePageKey, currentModulePageKey);
 	} 

	/**
	 * 从redis中获取前端页面
	 * 
	 * @param appCode
	 * @param pageCode
	 * @param orgId
	 * @return
	 */
	public Object getModulePageCache(String appCode, String pageCode, String orgId) {
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		if (StringUtils.isNotBlank(orgId)) {
			currentModulePageKey = currentModulePageKey + "-" + orgId;
		}
		String jsonStr = (String) redisTemplate.opsForValue().get(currentModulePageKey);
		if (StringUtils.isNotBlank(jsonStr)) {
			/** 读取的私有化页面 */
			System.out.println("读取的私有化页面 "+appCode+"  "+pageCode+"  "+orgId);
			return JSONObject.parseObject(jsonStr, IdeModulePrivate.class);
		}
		currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		System.out.println("读取公共页面 "+appCode+"  "+pageCode+"  "+orgId);
		jsonStr = (String) redisTemplate.opsForValue().get(currentModulePageKey);
		return JSONObject.parseObject(jsonStr, IdeModule.class);
	}

	/**
	 * 当前页面变动时或私有化后，删除该appCode和pageCode下所有缓存
	 * 
	 * @param appCode
	 * @param pageCode
	 */
	public void removeModulePageCache(String appCode, String pageCode) {
		String modulePageCacheKey = MODULEPAGE_CACHE_KEYS + appCode + "-" + pageCode;
		Set<Object> modulePageKeys = redisTemplate.opsForHash().keys(modulePageCacheKey);
		if(modulePageKeys != null && modulePageKeys.size() > 0) {
			for(Object key:modulePageKeys) {
				redisTemplate.delete(key.toString());
			}
		}
		redisTemplate.delete(modulePageCacheKey);
	}

}

==> ejc-front-impl-3.0.1-20230710.061131-158-sources.jar: com/ejianc/foundation/front/business/ide/cache/IdeModulePageCache.java <==
package com.ejianc.foundation.front.business.ide.cache;

import java.util.concurrent.TimeUnit;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.front.business.ide.entity.IdeModule;
import com.ejianc.foundation.front.business.ide.entity.IdeModulePrivate;

@Component
public class IdeModulePageCache {
	private static final Logger LOGGER = LoggerFactory.getLogger(IdeModulePageCache.class);
	// 当前模块的缓存Key
	private final static String CURRENT_MODULEPAGE_KEY = "current_modulepage_key:";

	@Autowired
	private RedisTemplate<String, Object> redisTemplate;

	/**
	 * 前端页面放入缓存
	 * 
	 * @param appCode
	 * @param pageCode
	 * @param orgId
	 */
	public void putModulePageCache(String appCode, String pageCode, String orgId, Object modulePro) {
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		if (StringUtils.isNotBlank(orgId)) {
			LOGGER.info("redisTemplate写入私有化页面 "+appCode+"  "+pageCode+"  "+orgId);
			currentModulePageKey = currentModulePageKey + "-" + orgId;
		}else {
			LOGGER.info("redisTemplate写入公共页面 "+appCode+"  "+pageCode+"  "+orgId);
		}
		String jsonStr = JSONObject.toJSONString(modulePro);

		redisTemplate.opsForValue().set(currentModulePageKey, jsonStr, 1, TimeUnit.DAYS);
 	}

	/**
	 * 从redis中获取前端页面
	 * 
	 * @param appCode
	 * @param pageCode
	 * @param orgId
	 * @return
	 */
	public Object getModulePageCache(String appCode, String pageCode) {
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		String jsonStr = (String) redisTemplate.opsForValue().get(currentModulePageKey);
		if(jsonStr==null){
			LOGGER.info("redisTemplate未读取到公共页面信息 "+appCode+"  "+pageCode );
			return null;
		}
		LOGGER.info("redisTemplate读取到了公共页面信息 "+appCode+"  "+pageCode );
		return JSONObject.parseObject(jsonStr, IdeModule.class);
	}

	/**
	 * 从redis中获取前端页面
	 *
	 * @param appCode
	 * @param pageCode
	 * @param orgId
	 * @return
	 */
	public Object getProvidePageCache(String appCode, String pageCode, String orgId) {
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		currentModulePageKey = currentModulePageKey + "-" + orgId;
		String jsonStr = (String) redisTemplate.opsForValue().get(currentModulePageKey);
		/** 读取的私有化页面 */
		if (StringUtils.isNotBlank(jsonStr)) {
			LOGGER.info("redisTemplate读取到了私有化页面信息 "+appCode+"  "+pageCode+" "+orgId );
			return JSONObject.parseObject(jsonStr, IdeModulePrivate.class);
		}
		LOGGER.info("redisTemplate未读取到私有化页面信息 "+appCode+"  "+pageCode+" "+orgId  );
		return null;
	}

	/**
	 * 当前页面变动时或私有化后，删除该appCode和pageCode下所有缓存
	 * 
	 * @param appCode
	 * @param pageCode
	 */
	public void removeModulePageCache(String appCode, String pageCode,String orgId) {
		String currentModulePageKey = CURRENT_MODULEPAGE_KEY + appCode + "-" + pageCode;
		if (StringUtils.isNotBlank(orgId)) {
			LOGGER.info("redisTemplate删除私有化页面 "+appCode+"  "+pageCode+"  "+orgId);
			currentModulePageKey = currentModulePageKey + "-" + orgId;
		}else {
			LOGGER.info("redisTemplate删除公共页面 "+appCode+"  "+pageCode+"  "+orgId);
		}
		redisTemplate.delete(currentModulePageKey);
	}

}
